@@ -29,6 +29,7 @@ import javax.faces.context.PartialResponseWriter;
 import javax.faces.context.ResponseWriter;
 
 import org.apache.myfaces.util.CDataEndEscapeFilterWriter;
+import org.apache.myfaces.util.IllegalXmlCharacterFilterWriter;
 
 /**
  * <p/>
@@ -64,8 +65,8 @@ import org.apache.myfaces.util.CDataEndEscapeFilterWriter;
  * For now I will only implement this in the impl, due to the spec stating
  * that implementations are responsible of the correct CDATA handling!
  *
- * @author Werner Punz (latest modification by $Author: lu4242 $)
- * @version $Revision: 1237538 $ $Date: 2012-01-30 03:43:13 +0000 (Mon, 30 Jan 2012) $
+ * @author Werner Punz (latest modification by $Author$)
+ * @version $Revision$ $Date$
  */
 
 public class PartialResponseWriterImpl extends PartialResponseWriter
@@ -109,7 +110,7 @@ public class PartialResponseWriterImpl extends PartialResponseWriter
 
     public PartialResponseWriterImpl(ResponseWriter writer)
     {
-        super(writer);
+        super(writer.cloneWithWriter(new IllegalXmlCharacterFilterWriter(writer)));
     }
 
     @Override
@@ -191,7 +192,7 @@ public class PartialResponseWriterImpl extends PartialResponseWriter
 
     private void popAndEncodeCurrentStackEntry() throws IOException
     {
-        StackEntry elem = _nestingStack.remove(0);
+        _nestingStack.remove(0);
         StackEntry parent = (_nestingStack.isEmpty()) ? null : _nestingStack.get(0);
         if (parent != null)
         {
