@@ -30,11 +30,9 @@ import javax.faces.component.UIParameter;
 import javax.faces.component.ValueHolder;
 import javax.faces.component.behavior.ClientBehavior;
 import javax.faces.component.behavior.ClientBehaviorContext;
-import javax.faces.component.behavior.ClientBehaviorHint;
 import javax.faces.component.behavior.ClientBehaviorHolder;
 import javax.faces.component.html.HtmlCommandButton;
 import javax.faces.component.html.HtmlCommandLink;
-import javax.faces.context.ExternalContext;
 import javax.faces.context.FacesContext;
 import javax.faces.context.ResponseWriter;
 import javax.faces.event.ActionEvent;
@@ -48,12 +46,6 @@ import org.apache.myfaces.shared.renderkit.html.util.JavascriptUtils;
 import org.apache.myfaces.shared.renderkit.html.util.ResourceUtils;
 import org.apache.myfaces.shared.util._ComponentUtils;
 
-/**
- * @author Manfred Geiler (latest modification by $Author: lu4242 $)
- * @author Thomas Spiegl
- * @author Anton Koinov
- * @version $Revision: 1669647 $ $Date: 2015-03-27 18:21:54 +0000 (Fri, 27 Mar 2015) $
- */
 public class HtmlButtonRendererBase
     extends HtmlRenderer
 {
@@ -118,8 +110,8 @@ public class HtmlButtonRendererBase
             || HtmlRendererUtils.isPartialOrBehaviorSubmit(facesContext, clientId);
     }
 
-    public void encodeEnd(FacesContext facesContext, UIComponent uiComponent)
-            throws IOException
+    @Override
+    public void encodeBegin(FacesContext facesContext, UIComponent uiComponent) throws IOException
     {
         org.apache.myfaces.shared.renderkit.RendererUtils.checkParamValidity(
                 facesContext, uiComponent, UICommand.class);
@@ -160,9 +152,7 @@ public class HtmlButtonRendererBase
         List<UIParameter> validParams = HtmlRendererUtils.getValidUIParameterChildren(
                 facesContext, childrenList, false, false);
         
-        boolean javascriptAllowed = JavascriptUtils.isJavascriptAllowed(facesContext.getExternalContext());
-        
-        if (formInfo != null && javascriptAllowed
+        if (formInfo != null 
                 && (MyfacesConfig.getCurrentInstance(facesContext.getExternalContext()).isAutoScroll() ||
                         (validParams != null && !validParams.isEmpty() )))
         {        
@@ -181,8 +171,6 @@ public class HtmlButtonRendererBase
         writer.writeAttribute(HTML.ID_ATTR, clientId, org.apache.myfaces.shared.renderkit.JSFAttr.ID_ATTR);
         writer.writeAttribute(HTML.NAME_ATTR, clientId, JSFAttr.ID_ATTR);
 
-        ExternalContext externalContext = facesContext.getExternalContext();
-
         String image = RendererUtils.getIconSrc(facesContext, uiComponent, JSFAttr.IMAGE_ATTR);
         if (image != null)
         {
@@ -207,8 +195,7 @@ public class HtmlButtonRendererBase
             }
         }
         
-        if (javascriptAllowed &&
-            (HtmlRendererUtils.hasClientBehavior(ClientBehaviorEvents.CLICK, behaviors, facesContext) ||
+        if ((HtmlRendererUtils.hasClientBehavior(ClientBehaviorEvents.CLICK, behaviors, facesContext) ||
              HtmlRendererUtils.hasClientBehavior(ClientBehaviorEvents.ACTION, behaviors, facesContext)))
         {
             if (!reset && !button)
@@ -217,7 +204,7 @@ public class HtmlButtonRendererBase
                         uiComponent, behaviors, facesContext, writer, formInfo, validParams);
                 if (onClick.length() != 0)
                 {
-                    writer.writeAttribute(HTML.ONCLICK_ATTR, onClick.toString(), null);
+                    writer.writeAttribute(HTML.ONCLICK_ATTR, onClick, null);
                 }
             }
             else
@@ -231,7 +218,7 @@ public class HtmlButtonRendererBase
                         commandOnclick , null);
                 if (onClick.length() != 0)
                 {
-                    writer.writeAttribute(HTML.ONCLICK_ATTR, onClick.toString(), null);
+                    writer.writeAttribute(HTML.ONCLICK_ATTR, onClick, null);
                 }
             }
             
@@ -241,7 +228,7 @@ public class HtmlButtonRendererBase
                     facesContext, uiComponent, ClientBehaviorEvents.DBLCLICK, null, behaviors,   
                         (String) attributes.get(HTML.ONDBLCLICK_ATTR), "");
         }
-        else if (javascriptAllowed)
+        else
         {
             //fallback into the pre 2.0 code to keep backwards compatibility with libraries which rely on internals
             if (!reset && !button)
@@ -306,9 +293,16 @@ public class HtmlButtonRendererBase
             writer.writeAttribute(HTML.READONLY_ATTR, Boolean.TRUE, 
                     org.apache.myfaces.shared.renderkit.JSFAttr.READONLY_ATTR);
         }
+    }
+    
+    public void encodeEnd(FacesContext facesContext, UIComponent uiComponent)
+            throws IOException
+    {
+        ResponseWriter writer = facesContext.getResponseWriter();
 
         writer.endElement(HTML.INPUT_ELEM);
         
+        FormInfo formInfo = findNestingForm(uiComponent, facesContext);
         if (formInfo != null)
         {
             HtmlFormRendererBase.renderScrollHiddenInputIfNecessary(
@@ -328,22 +322,6 @@ public class HtmlButtonRendererBase
         }*/
     }
 
-    private boolean hasSubmittingBehavior(Map<String, List<ClientBehavior>> clientBehaviors, String eventName)
-    {
-        List<ClientBehavior> eventBehaviors = clientBehaviors.get(eventName);
-        if (eventBehaviors != null && !eventBehaviors.isEmpty())
-        {
-            for (ClientBehavior behavior : eventBehaviors)
-            {
-                if (behavior.getHints().contains(ClientBehaviorHint.SUBMITTING))
-                {
-                    return true;
-                }
-            }
-        }
-        return false;
-    }
-    
     protected String buildBehaviorizedOnClick(UIComponent uiComponent, Map<String, List<ClientBehavior>> behaviors, 
                                               FacesContext facesContext, ResponseWriter writer, 
                                               FormInfo nestedFormInfo, List<UIParameter> validParams)
@@ -420,24 +398,14 @@ public class HtmlButtonRendererBase
         }
         else
         {
-            StringBuilder params = addChildParameters(facesContext, component, nestingForm, validParams);
+            StringBuilder params = addChildParameters(facesContext, nestingForm, validParams);
 
             String target = getTarget(component);
 
-            if (MyfacesConfig.getCurrentInstance(facesContext.getExternalContext()).isRenderFormSubmitScriptInline())
-            {
-                onClick.append("return ").
-                    append(HtmlRendererUtils.SUBMIT_FORM_FN_NAME).append("('").
-                    append(formName).append("','").
-                    append(component.getClientId(facesContext)).append("'");                    
-            }
-            else
-            {
-                onClick.append("return ").
-                    append(HtmlRendererUtils.SUBMIT_FORM_FN_NAME_JSF2).append("('").
-                    append(formName).append("','").
-                    append(component.getClientId(facesContext)).append("'");
-            }
+            onClick.append("return ").
+                append(HtmlRendererUtils.SUBMIT_FORM_FN_NAME_JSF2).append("('").
+                append(formName).append("','").
+                append(component.getClientId(facesContext)).append("'");
 
             if (params.length() > 2 || target != null)
             {
@@ -456,7 +424,7 @@ public class HtmlButtonRendererBase
         return onClick.toString();
     }
     
-    private StringBuilder addChildParameters(FacesContext context, UIComponent component, 
+    private StringBuilder addChildParameters(FacesContext context, 
             UIComponent nestingForm, List<UIParameter> validParams)
     {
         //add child parameters
@@ -596,25 +564,14 @@ public class HtmlButtonRendererBase
             if (validParams != null && !validParams.isEmpty() )
             {
                 StringBuilder params = addChildParameters(
-                        facesContext, uiComponent, nestedFormInfo.getForm(), validParams);
+                        facesContext, nestedFormInfo.getForm(), validParams);
 
                 String target = getTarget(uiComponent);
 
-                if (MyfacesConfig.getCurrentInstance(
-                        facesContext.getExternalContext()).isRenderFormSubmitScriptInline())
-                {
-                    onClick.append("return ").
-                        append(HtmlRendererUtils.SUBMIT_FORM_FN_NAME).append("('").
-                        append(formName).append("','").
-                        append(uiComponent.getClientId(facesContext)).append("'");                    
-                }
-                else
-                {
-                    onClick.append("return ").
-                        append(HtmlRendererUtils.SUBMIT_FORM_FN_NAME_JSF2).append("('").
-                        append(formName).append("','").
-                        append(uiComponent.getClientId(facesContext)).append("'");
-                }
+                onClick.append("return ").
+                    append(HtmlRendererUtils.SUBMIT_FORM_FN_NAME_JSF2).append("('").
+                    append(formName).append("','").
+                    append(uiComponent.getClientId(facesContext)).append("'");
 
                 if (params.length() > 2 || target != null)
                 {
@@ -712,15 +669,6 @@ public class HtmlButtonRendererBase
                 uiComponent, HTML.READONLY_ATTR, false);
     }
 
-    private String getImage(UIComponent uiComponent)
-    {
-        if (uiComponent instanceof HtmlCommandButton)
-        {
-            return ((HtmlCommandButton)uiComponent).getImage();
-        }
-        return (String)uiComponent.getAttributes().get(JSFAttr.IMAGE_ATTR);
-    }
-
     private String getType(UIComponent uiComponent)
     {
         if (uiComponent instanceof HtmlCommandButton)
