@@ -30,6 +30,7 @@ import javax.faces.context.ExternalContext;
 import javax.faces.webapp.FacesServlet;
 
 import org.apache.myfaces.shared.config.MyfacesConfig;
+import org.apache.myfaces.shared.util.ClassUtils;
 
 /**
  * @author Manfred Geiler (latest modification by $Author$)
@@ -113,7 +114,10 @@ public class WebXml
 
     public List getFacesServletMappings()
     {
-        if (_facesServletMappings != null) return _facesServletMappings;
+        if (_facesServletMappings != null)
+        {
+            return _facesServletMappings;
+        }
 
         List tempFacesServletMappings = new ArrayList();
         for (Iterator it = _servlets.entrySet().iterator(); it.hasNext(); )
@@ -130,7 +134,17 @@ public class WebXml
                 // </servlet>
                 continue;
             }
-            Class servletClass = org.apache.myfaces.shared.util.ClassUtils.simpleClassForName((String)entry.getValue());
+
+            Class servletClass = ClassUtils.simpleClassForName((String) entry.getValue(), false);
+            if (servletClass == null)
+            {
+                if (log.isLoggable(Level.FINEST))
+                {
+                    log.finest("ignoring servlet " + servletName + " because its class could not be loaded");
+                }
+                continue;
+            }
+
             if (FacesServlet.class.isAssignableFrom(servletClass) ||
                     DelegatedFacesServlet.class.isAssignableFrom(servletClass) ||
                     servletClass.getName().equals(_delegateFacesServlet))
@@ -141,17 +155,20 @@ public class WebXml
                     for (Iterator it2 = urlPatterns.iterator(); it2.hasNext(); )
                     {
                         String urlpattern = (String)it2.next();
-                        tempFacesServletMappings.add(new org.apache.myfaces.shared_impl.webapp.webxml.ServletMapping(servletName,
-                                                                                                             servletClass,
-                                                                                                             urlpattern));
+                        tempFacesServletMappings.add(new ServletMapping(servletName, servletClass, urlpattern));
                         if (log.isLoggable(Level.FINEST))
+                        {
                             log.finest("adding mapping for servlet + " + servletName + " urlpattern = " + urlpattern);
+                        }
                     }
                 }
             }
             else
             {
-                if (log.isLoggable(Level.FINEST)) log.finest("ignoring servlet + " + servletName + " " + servletClass + " (no FacesServlet)");
+                if (log.isLoggable(Level.FINEST))
+                {
+                    log.finest("ignoring servlet + " + servletName + " " + servletClass + " (no FacesServlet)");
+                }
             }
         }
         
@@ -167,7 +184,10 @@ public class WebXml
      */
     public List getFacesExtensionsFilterMappings()
     {
-        if (_facesExtensionsFilterMappings != null) return _facesExtensionsFilterMappings;
+        if (_facesExtensionsFilterMappings != null)
+        {
+            return _facesExtensionsFilterMappings;
+        }
 
         List tempExtensionsFilterMappings = new ArrayList();
         for (Iterator it = _filters.entrySet().iterator(); it.hasNext(); )
@@ -193,7 +213,9 @@ public class WebXml
                     tempExtensionsFilterMappings.add(new org.apache.myfaces.shared_impl.webapp.webxml.FilterMapping(
                         filterName, filterClass, urlpattern));
                     if (log.isLoggable(Level.FINEST))
+                    {
                         log.finest("adding mapping for filter + " + filterName + " urlpattern = " + urlpattern);
+                    }
                 }
             }
         }
@@ -234,9 +256,11 @@ public class WebXml
 
     protected boolean isOld(ExternalContext context)
     {
-        if (refreshPeriod > 0) {
+        if (refreshPeriod > 0)
+        {
             long ttl = this.parsingTime + refreshPeriod;
-            if (System.currentTimeMillis() > ttl) {
+            if (System.currentTimeMillis() > ttl)
+            {
                 long lastModified = WebXmlParser.getWebXmlLastModified(context);
                 return lastModified == 0 || lastModified > ttl;
             }
@@ -274,7 +298,8 @@ public class WebXml
 
     public static void update(ExternalContext context)
     {
-        if (getWebXml(context).isOld(context)){
+        if (getWebXml(context).isOld(context))
+        {
             WebXml.init(context);
         }
     }
