@@ -24,6 +24,7 @@ import javax.el.ELException;
 import javax.el.ExpressionFactory;
 import javax.el.MethodExpression;
 import javax.el.ValueExpression;
+import javax.faces.component.UIComponent;
 import javax.faces.view.Location;
 import javax.faces.view.facelets.FaceletContext;
 import javax.faces.view.facelets.TagAttribute;
@@ -39,6 +40,9 @@ import org.apache.myfaces.view.facelets.el.ELText;
 import org.apache.myfaces.view.facelets.el.LocationMethodExpression;
 import org.apache.myfaces.view.facelets.el.LocationValueExpression;
 import org.apache.myfaces.view.facelets.el.LocationValueExpressionUEL;
+import org.apache.myfaces.view.facelets.el.ResourceELUtils;
+import org.apache.myfaces.view.facelets.el.ResourceLocationValueExpression;
+import org.apache.myfaces.view.facelets.el.ResourceLocationValueExpressionUEL;
 import org.apache.myfaces.view.facelets.el.TagMethodExpression;
 import org.apache.myfaces.view.facelets.el.TagValueExpression;
 import org.apache.myfaces.view.facelets.el.TagValueExpressionUEL;
@@ -59,6 +63,8 @@ public final class TagAttributeImpl extends TagAttribute
     
     private final static int EL_CC_ATTR_ME = 4;
     
+    private final static int EL_RESOURCE = 8;
+    
     private final int capabilities;
 
     private final String localName;
@@ -86,9 +92,13 @@ public final class TagAttributeImpl extends TagAttribute
         boolean literal;
         boolean compositeComponentExpression;
         boolean compositeComponentAttrMethodExpression;
+        boolean resourceExpression;
         this.location = location;
         this.namespace = ns;
-        this.localName = localName;
+        // "xmlns" attribute name can be swallowed by SAX compiler, so we should check if
+        // localName is null or empty and if that so, assign it from the qName 
+        // (if localName is empty it is not prefixed, so it is save to set it directly). 
+        this.localName = (localName == null) ? qName : ((localName.length() > 0) ? localName : qName);
         this.qName = qName;
         this.value = value;
 
@@ -107,8 +117,10 @@ public final class TagAttributeImpl extends TagAttribute
         compositeComponentAttrMethodExpression = compositeComponentExpression ? 
                 CompositeComponentELUtils.isCompositeComponentAttrsMethodExpression(this.value) : 
                     false;
+        resourceExpression = !literal ? ResourceELUtils.isResourceExpression(this.value) : false;
 
-        this.capabilities = (literal ? EL_LITERAL : 0) | (compositeComponentExpression ? EL_CC : 0) | (compositeComponentAttrMethodExpression ? EL_CC_ATTR_ME : 0); 
+        this.capabilities = (literal ? EL_LITERAL : 0) | (compositeComponentExpression ? EL_CC : 0) | 
+            (compositeComponentAttrMethodExpression ? EL_CC_ATTR_ME : 0) | ( resourceExpression ? EL_RESOURCE : 0); 
     }
 
     /**
@@ -209,6 +221,17 @@ public final class TagAttributeImpl extends TagAttribute
                     if ((this.capabilities & EL_CC) != 0 &&
                         localCachedExpression[(i*3)+2] instanceof LocationMethodExpression)
                     {
+                        UIComponent cc = actx.getFaceletCompositionContext().getCompositeComponentFromStack();
+                        if (cc != null)
+                        {
+                            Location location = (Location) cc.getAttributes().get(
+                                    CompositeComponentELUtils.LOCATION_KEY);
+                            if (location != null)
+                            {
+                                return ((LocationMethodExpression)localCachedExpression[(i*3)+2]).apply(
+                                        actx.getFaceletCompositionContext().getCompositeComponentLevel(), location);
+                            }
+                        }
                         return ((LocationMethodExpression)localCachedExpression[(i*3)+2]).apply(
                                 actx.getFaceletCompositionContext().getCompositeComponentLevel());
                     }
@@ -276,7 +299,18 @@ public final class TagAttributeImpl extends TagAttribute
                 // (see MYFACES-2561 for details)
                 if ((this.capabilities & EL_CC) != 0)
                 {
-                    methodExpression = new LocationMethodExpression(getLocation(), methodExpression, 
+                    Location currentLocation = getLocation();
+                    Location ccLocation = (Location) actx.getFaceletCompositionContext().
+                            getCompositeComponentFromStack().getAttributes().get(
+                                    CompositeComponentELUtils.LOCATION_KEY);
+                    if (ccLocation != null && !ccLocation.getPath().equals(currentLocation.getPath()))
+                    {
+                        // #{cc} from a template called from inside a composite component, disable caching on 
+                        // this expression. The reason is we need to change the Location object used as
+                        // reference as the one in the stack, and that depends on the template hierarchy.
+                        currentLocation = ccLocation;
+                    }
+                    methodExpression = new LocationMethodExpression(currentLocation, methodExpression, 
                             actx.getFaceletCompositionContext().getCompositeComponentLevel());
                 }
             }
@@ -451,6 +485,17 @@ public final class TagAttributeImpl extends TagAttribute
                 // If #{cc} recalculate the composite component level
                 if ((this.capabilities & EL_CC) != 0)
                 {
+                    UIComponent cc = actx.getFaceletCompositionContext().getCompositeComponentFromStack();
+                    if (cc != null)
+                    {
+                        Location location = (Location) cc.getAttributes().get(
+                                CompositeComponentELUtils.LOCATION_KEY);
+                        if (location != null)
+                        {
+                            return ((LocationValueExpression)localCachedExpression[1]).apply(
+                                    actx.getFaceletCompositionContext().getCompositeComponentLevel(), location);
+                        }
+                    }
                     return ((LocationValueExpression)localCachedExpression[1]).apply(
                             actx.getFaceletCompositionContext().getCompositeComponentLevel());
                 }
@@ -461,6 +506,17 @@ public final class TagAttributeImpl extends TagAttribute
                 // If #{cc} recalculate the composite component level
                 if ((this.capabilities & EL_CC) != 0)
                 {
+                    UIComponent cc = actx.getFaceletCompositionContext().getCompositeComponentFromStack();
+                    if (cc != null)
+                    {
+                        Location location = (Location) cc.getAttributes().get(
+                                CompositeComponentELUtils.LOCATION_KEY);
+                        if (location != null)
+                        {
+                            return ((LocationValueExpression)localCachedExpression[1]).apply(
+                                    actx.getFaceletCompositionContext().getCompositeComponentLevel(), location);
+                        }
+                    }
                     return ((LocationValueExpression)localCachedExpression[1]).apply(
                             actx.getFaceletCompositionContext().getCompositeComponentLevel());
                 }
@@ -504,17 +560,45 @@ public final class TagAttributeImpl extends TagAttribute
             // (see MYFACES-2561 for details)
             if ((this.capabilities & EL_CC) != 0)
             {
+                // In MYFACES-4099 it was found that #{cc} could happen outside a composite component. In that
+                // case, getLocation() will point to the template. To solve the problem, it is better to get
+                // the location of the composite component from the stack directly, but only when the path
+                // is different.
+                Location currentLocation = getLocation();
+                Location ccLocation = (Location) actx.getFaceletCompositionContext().
+                        getCompositeComponentFromStack().getAttributes().get(
+                                CompositeComponentELUtils.LOCATION_KEY);
+                if (ccLocation != null && !ccLocation.getPath().equals(currentLocation.getPath()))
+                {
+                    // #{cc} from a template called from inside a composite component, disable caching on 
+                    // this expression. The reason is we need to change the Location object used as
+                    // reference as the one in the stack, and that depends on the template hierarchy.
+                    //cacheable = false;
+                    currentLocation = ccLocation;
+                }
                 if (ExternalSpecifications.isUnifiedELAvailable())
                 {
-                    valueExpression = new LocationValueExpressionUEL(getLocation(), valueExpression, 
+                    valueExpression = new LocationValueExpressionUEL(currentLocation, valueExpression, 
                             actx.getFaceletCompositionContext().getCompositeComponentLevel());
                 }
                 else
                 {
-                    valueExpression = new LocationValueExpression(getLocation(), valueExpression, 
+                    valueExpression = new LocationValueExpression(currentLocation, valueExpression, 
                             actx.getFaceletCompositionContext().getCompositeComponentLevel());
                 }
             }
+            else if ((this.capabilities & EL_RESOURCE) != 0)
+            {
+                if (ExternalSpecifications.isUnifiedELAvailable())
+                {
+                    valueExpression = new ResourceLocationValueExpressionUEL(getLocation(), valueExpression);
+                }
+                else
+                {
+                    valueExpression = new ResourceLocationValueExpression(getLocation(), valueExpression);
+                }
+            }
+            
             
             if (actx.isAllowCacheELExpressions() && !actx.isAnyFaceletsVariableResolved())
             {
