@@ -18,7 +18,6 @@
  */
 package javax.faces.bean;
 
-import java.lang.annotation.Documented;
 import java.lang.annotation.ElementType;
 import java.lang.annotation.Inherited;
 import java.lang.annotation.Retention;
@@ -26,10 +25,7 @@ import java.lang.annotation.Target;
 
 /**
  * @since 2.0
- * @author Leonardo Uribe (latest modification by $Author$)
- * @version $Revision$ $Date$
  */
-@Documented
 @Retention(java.lang.annotation.RetentionPolicy.CLASS)
 @Target(ElementType.TYPE)
 @Inherited
