@@ -44,11 +44,13 @@ import javax.faces.render.FacesBehaviorRenderer;
 import javax.faces.render.FacesRenderer;
 import javax.faces.render.RenderKitFactory;
 import javax.faces.validator.FacesValidator;
+import javax.faces.view.facelets.FaceletsResourceResolver;
 
-import org.apache.myfaces.config.impl.digester.elements.Application;
-import org.apache.myfaces.config.impl.digester.elements.Behavior;
-import org.apache.myfaces.config.impl.digester.elements.Converter;
-import org.apache.myfaces.config.impl.digester.elements.FacesConfig;
+import org.apache.myfaces.config.impl.digester.elements.ApplicationImpl;
+import org.apache.myfaces.config.impl.digester.elements.BehaviorImpl;
+import org.apache.myfaces.config.impl.digester.elements.ComponentTagDeclarationImpl;
+import org.apache.myfaces.config.impl.digester.elements.ConverterImpl;
+import org.apache.myfaces.config.impl.digester.elements.FacesConfigImpl;
 import org.apache.myfaces.spi.AnnotationProvider;
 import org.apache.myfaces.spi.AnnotationProviderFactory;
 
@@ -69,8 +71,8 @@ import org.apache.myfaces.spi.AnnotationProviderFactory;
  * </p>
  *
  * @since 2.0
- * @author Leonardo Uribe (latest modification by $Author: lu4242 $)
- * @version $Revision: 1455392 $ $Date: 2013-03-12 02:17:31 +0000 (Tue, 12 Mar 2013) $
+ * @author Leonardo Uribe (latest modification by $Author$)
+ * @version $Revision$ $Date$
  */
 public class AnnotationConfigurator
 {
@@ -81,7 +83,7 @@ public class AnnotationConfigurator
     {
     }
 
-    public FacesConfig createFacesConfig(ExternalContext externalcontext, boolean metadataComplete)
+    public FacesConfigImpl createFacesConfig(ExternalContext externalcontext, boolean metadataComplete)
     {
         if (!metadataComplete)
         {
@@ -99,9 +101,9 @@ public class AnnotationConfigurator
      * @param map
      * @return
      */
-    protected FacesConfig createFacesConfig(Map<Class<? extends Annotation>, Set<Class<?>>> map)
+    protected FacesConfigImpl createFacesConfig(Map<Class<? extends Annotation>, Set<Class<?>>> map)
     {
-        FacesConfig facesConfig = new FacesConfig();
+        FacesConfigImpl facesConfig = new FacesConfigImpl();
 
         Set<Class<?>> classes = map.get(FacesComponent.class);
 
@@ -118,8 +120,31 @@ public class AnnotationConfigurator
                         log.finest("addComponent(" + comp.value() + ","
                                 + clazz.getName() + ")");
                     }
-
-                    facesConfig.addComponent(comp.value(), clazz.getName());
+                    String value = comp.value();
+                    if ( value == null ||
+                        (value != null && value.length() <= 0))
+                    {
+                        String simpleName = clazz.getSimpleName();
+                        value = Character.toLowerCase(simpleName.charAt(0)) + simpleName.substring(1);
+                    }
+                    facesConfig.addComponent(value, clazz.getName());
+                    
+                    if (comp.createTag())
+                    {
+                        String tagName = comp.tagName();
+                        if (tagName != null && tagName.length() > 0)
+                        {
+                            //Ok
+                        }
+                        else
+                        {
+                            tagName = clazz.getSimpleName();
+                            tagName = Character.toLowerCase(tagName.charAt(0)) + tagName.substring(1);
+                        }
+                        facesConfig.addComponentTagDeclaration(value, 
+                                new ComponentTagDeclarationImpl(value, 
+                                    comp.namespace(), tagName));
+                    }
                 }
             }
         }
@@ -144,7 +169,7 @@ public class AnnotationConfigurator
                     boolean hasValue = conv.value().length() > 0;
                     if (hasForClass || hasValue)
                     {
-                        Converter converter = new Converter();
+                        ConverterImpl converter = new ConverterImpl();
                         if (hasForClass)
                         {
                             converter.setForClass(conv.forClass().getName());
@@ -180,19 +205,26 @@ public class AnnotationConfigurator
                         log.finest("addValidator(" + val.value() + "," + clazz.getName()
                                 + ")");
                     }
-                    facesConfig.addValidator(val.value(), clazz.getName());
+                    String value = val.value();
+                    if ( value == null ||
+                        (value != null && value.length() <= 0))
+                    {
+                        String simpleName = clazz.getSimpleName();
+                        value = Character.toLowerCase(simpleName.charAt(0)) + simpleName.substring(1);
+                    }
+                    facesConfig.addValidator(value, clazz.getName());
                     if (val.isDefault())
                     {
-                        Application app = null;
+                        ApplicationImpl app = null;
                         if (facesConfig.getApplications().isEmpty())
                         {
-                            app = new Application();
+                            app = new ApplicationImpl();
                         }
                         else
                         {
-                            app = (Application) facesConfig.getApplications().get(0);
+                            app = (ApplicationImpl) facesConfig.getApplications().get(0);
                         }
-                        app.addDefaultValidatorId(val.value());
+                        app.addDefaultValidatorId(value);
                     }
                 }
             }
@@ -219,18 +251,18 @@ public class AnnotationConfigurator
                                 + ", " + clazz.getName() + ")");
                     }
 
-                    org.apache.myfaces.config.impl.digester.elements.RenderKit renderKit =
-                            (org.apache.myfaces.config.impl.digester.elements.RenderKit)
+                    org.apache.myfaces.config.impl.digester.elements.RenderKitImpl renderKit =
+                            (org.apache.myfaces.config.impl.digester.elements.RenderKitImpl)
                                     facesConfig.getRenderKit(renderKitId);
                     if (renderKit == null)
                     {
-                        renderKit = new org.apache.myfaces.config.impl.digester.elements.RenderKit();
+                        renderKit = new org.apache.myfaces.config.impl.digester.elements.RenderKitImpl();
                         renderKit.setId(renderKitId);
                         facesConfig.addRenderKit(renderKit);
                     }
 
-                    org.apache.myfaces.config.impl.digester.elements.Renderer renderer =
-                            new org.apache.myfaces.config.impl.digester.elements.Renderer();
+                    org.apache.myfaces.config.impl.digester.elements.RendererImpl renderer =
+                            new org.apache.myfaces.config.impl.digester.elements.RendererImpl();
                     renderer.setComponentFamily(rend.componentFamily());
                     renderer.setRendererClass(clazz.getName());
                     renderer.setRendererType(rend.rendererType());
@@ -262,10 +294,17 @@ public class AnnotationConfigurator
         {
             handleFacesBehaviorRenderer(facesConfig, classes);
         }
+        
+        classes = map.get(FaceletsResourceResolver.class);
+        if (classes != null && !classes.isEmpty())
+        {
+            handleFaceletsResourceResolver(facesConfig, classes);
+        }
+        
         return facesConfig;
     }
     
-    private void handleManagedBean(FacesConfig facesConfig, Set<Class<?>> classes)
+    private void handleManagedBean(FacesConfigImpl facesConfig, Set<Class<?>> classes)
     {
         for (Class<?> clazz : classes)
         {
@@ -279,8 +318,8 @@ public class AnnotationConfigurator
                     log.fine("Class '" + clazz.getName() + "' has an @ManagedBean annotation");
                 }
 
-                org.apache.myfaces.config.impl.digester.elements.ManagedBean mbc =
-                        new org.apache.myfaces.config.impl.digester.elements.ManagedBean();
+                org.apache.myfaces.config.impl.digester.elements.ManagedBeanImpl mbc =
+                        new org.apache.myfaces.config.impl.digester.elements.ManagedBeanImpl();
                 String beanName = bean.name();
 
                 if ((beanName == null) || beanName.equals(""))
@@ -291,7 +330,7 @@ public class AnnotationConfigurator
                     // first character lowercase.
 
                     beanName = clazz.getName();
-                    index = beanName.lastIndexOf(".");
+                    index = beanName.lastIndexOf('.');
 
                     if (index != -1)
                     {
@@ -381,8 +420,8 @@ public class AnnotationConfigurator
                             log.fine("  Field '" + field.getName()
                                     + "' has a @ManagedProperty annotation");
                         }
-                        org.apache.myfaces.config.impl.digester.elements.ManagedProperty mpc =
-                                new org.apache.myfaces.config.impl.digester.elements.ManagedProperty();
+                        org.apache.myfaces.config.impl.digester.elements.ManagedPropertyImpl mpc =
+                                new org.apache.myfaces.config.impl.digester.elements.ManagedPropertyImpl();
                         String name = property.name();
                         if ((name == null) || "".equals(name))
                         {
@@ -400,7 +439,7 @@ public class AnnotationConfigurator
         }
     }
     
-    private void handleNamedEvent(FacesConfig facesConfig, Set<Class<?>> classes)
+    private void handleNamedEvent(FacesConfigImpl facesConfig, Set<Class<?>> classes)
     {
         for (Class<?> clazz : classes)
         {
@@ -423,8 +462,8 @@ public class AnnotationConfigurator
                 // Have to register @NamedEvent annotations with the NamedEventManager class since
                 // we need to get access to this info later and can't from the dispenser (it's not a
                 // singleton).
-                org.apache.myfaces.config.impl.digester.elements.NamedEvent namedEventConfig =
-                        new org.apache.myfaces.config.impl.digester.elements.NamedEvent();
+                org.apache.myfaces.config.impl.digester.elements.NamedEventImpl namedEventConfig =
+                        new org.apache.myfaces.config.impl.digester.elements.NamedEventImpl();
                 namedEventConfig.setEventClass(clazz.getName());
                 namedEventConfig.setShortName(namedEvent.shortName());
                 facesConfig.addNamedEvent(namedEventConfig);
@@ -432,7 +471,7 @@ public class AnnotationConfigurator
         }
     }
 
-    private void handleFacesBehavior(FacesConfig facesConfig, Set<Class<?>> classes)
+    private void handleFacesBehavior(FacesConfigImpl facesConfig, Set<Class<?>> classes)
     {
         for (Class<?> clazz : classes)
         {
@@ -459,7 +498,7 @@ public class AnnotationConfigurator
                     log.finest("addBehavior(" + facesBehavior.value() + ", " + clazz.getName() + ")");
                 }
 
-                Behavior behavior = new Behavior();
+                BehaviorImpl behavior = new BehaviorImpl();
                 behavior.setBehaviorId(facesBehavior.value());
                 behavior.setBehaviorClass(clazz.getName());
                 facesConfig.addBehavior(behavior);
@@ -468,7 +507,7 @@ public class AnnotationConfigurator
         }
     }
     
-    private void handleFacesBehaviorRenderer(FacesConfig facesConfig, Set<Class<?>> classes)
+    private void handleFacesBehaviorRenderer(FacesConfigImpl facesConfig, Set<Class<?>> classes)
     {
         for (Class<?> clazz : classes)
         {
@@ -487,24 +526,38 @@ public class AnnotationConfigurator
                                + clazz.getName() + ")");
                 }
 
-                org.apache.myfaces.config.impl.digester.elements.RenderKit renderKit =
-                        (org.apache.myfaces.config.impl.digester.elements.RenderKit)
+                org.apache.myfaces.config.impl.digester.elements.RenderKitImpl renderKit =
+                        (org.apache.myfaces.config.impl.digester.elements.RenderKitImpl)
                                 facesConfig.getRenderKit(renderKitId);
                 if (renderKit == null)
                 {
-                    renderKit = new org.apache.myfaces.config.impl.digester.elements.RenderKit();
+                    renderKit = new org.apache.myfaces.config.impl.digester.elements.RenderKitImpl();
                     renderKit.setId(renderKitId);
                     facesConfig.addRenderKit(renderKit);
                 }
 
-                org.apache.myfaces.config.impl.digester.elements.ClientBehaviorRenderer cbr =
-                        new org.apache.myfaces.config.impl.digester.elements.ClientBehaviorRenderer();
+                org.apache.myfaces.config.impl.digester.elements.ClientBehaviorRendererImpl cbr =
+                        new org.apache.myfaces.config.impl.digester.elements.ClientBehaviorRendererImpl();
                 cbr.setRendererType(facesBehaviorRenderer.rendererType());
                 cbr.setRendererClass(clazz.getName());
                 renderKit.addClientBehaviorRenderer(cbr);
             }
         }
     }
+    
+    private void handleFaceletsResourceResolver(FacesConfigImpl facesConfig, Set<Class<?>> classes)
+    {
+        for (Class<?> clazz : classes)
+        {
+            FaceletsResourceResolver faceletsResourceResolver = 
+                (FaceletsResourceResolver) clazz.getAnnotation(FaceletsResourceResolver.class);
+            
+            if (faceletsResourceResolver != null)
+            {
+                facesConfig.addResourceResolver(clazz.getName());
+            }
+        }
+    }
 
     /**
      * <p>Return an array of all <code>Field</code>s reflecting declared
